Rename record structs to report for clarity

Bug: 243163572
Test: citadel_updater --dauntless --[big_]event

Signed-off-by: Kevin Zhang <zhakevin@google.com>
Change-Id: I73fb2aad1289b607cc8101330c2b616a11733d55
Merged-In: Ic2a09de65b0f0b44dcc2ac5fd5e5a0f06f4e4f2e
Reviewed-on: https://nugget-os-review.googlesource.com/c/host/generic/+/53905
Presubmit-Verified: TreeHugger Robot <android-build-prod@system.gserviceaccount.com>
Reviewed-by: Bill Richardson <wfrichar@google.com>
diff --git a/nugget/include/app_nugget.h b/nugget/include/app_nugget.h
index 1b1ffff..cbeac47 100644
--- a/nugget/include/app_nugget.h
+++ b/nugget/include/app_nugget.h
@@ -299,15 +299,15 @@
   uint32_t inv;                         /* must equal ~type when setting */
 } __packed;
 
-#define NUGGET_PARAM_GET_EVENT_RECORD 0x0010
+#define NUGGET_PARAM_GET_EVENT_REPORT 0x0010
 /*
- * This retrieves one pending event_record (defined in citadel_events.h).
+ * This retrieves one pending event_report (defined in citadel_events.h).
  * If none are pending, it returns nothing.
  *
  * @param args         <none>
  * @param arg_len      0
- * @param reply        struct event_record
- * @param reply_len    sizeof struct event_record  OR  0
+ * @param reply        struct event_report
+ * @param reply_len    sizeof struct event_report  OR  0
  */
 
 #define NUGGET_PARAM_AP_IS_REBOOTING 0x0011
@@ -564,15 +564,15 @@
  * @param reply        <none>
  * @param reply_len    0
  */
-#define NUGGET_PARAM_GET_BIG_EVENT_RECORD 0x001b
+#define NUGGET_PARAM_GET_BIG_EVENT_REPORT 0x001b
 /*
- * This retrieves one pending big_event_record (defined in citadel_events.h).
+ * This retrieves one pending big_event_report (defined in citadel_events.h).
  * If none are pending, it returns nothing.
  *
  * @param args         <none>
  * @param arg_len      0
- * @param reply        struct big_event_record
- * @param reply_len    sizeof struct big_event_record  OR  0
+ * @param reply        struct big_event_report
+ * @param reply_len    sizeof struct big_event_report  OR  0
  */
 
 /****************************************************************************/
diff --git a/nugget/include/citadel_events.h b/nugget/include/citadel_events.h
index 3be579e..00780ad 100644
--- a/nugget/include/citadel_events.h
+++ b/nugget/include/citadel_events.h
@@ -31,7 +31,7 @@
  * When Citadel needs to tell the AP something without waiting to be asked, the
  * process is as follows:
  *
  *   1. Citadel adds an event_record to its internal queue, then asserts
  *      the CTDL_AP_IRQ signal to notify the AP.
  *
  *   2. The AP (citadeld) requests pending events from Citadel until they've
@@ -66,7 +66,7 @@
   EVENT_ALERT_V2 = 4,      // Globalsec Alertv2 fired
   EVENT_SEC_CH_STATE = 5,  // Update GSA-GSC secure channel state.
   EVENT_V1_NO_SUPPORT =
-      6  // Report a VXX event that can't fit in struct small_event_record.
+      6  // Report a VXX event that can't fit in struct event_report.
 };
 
 /*
@@ -87,8 +87,8 @@
 };
 
 /* Please do not change the size of this struct */
-#define EVENT_RECORD_SIZE 64
-struct event_record {
+#define EVENT_REPORT_SIZE 64
+struct event_report {
   uint64_t reset_count;                 /* zeroed by Citadel power cycle */
   uint64_t uptime_usecs;                /* since last Citadel reset */
   uint32_t id;
@@ -127,10 +127,10 @@
   } event;
 } __packed;
 /* Please do not change the size of this struct */
-static_assert(sizeof(struct event_record) == EVENT_RECORD_SIZE,
+static_assert(sizeof(struct event_report) == EVENT_REPORT_SIZE,
               "Muting the Immutable");
 
-struct big_event_record {
+struct big_event_report {
   struct hdr {
     /* Redundant w.r.t. to v1 event records */
     uint64_t reset_count;
@@ -31,7 +31,7 @@
  * process is as follows:
  *
- *   1. Citadel adds an event_record to its internal queue, then asserts
+ *   1. Citadel adds an event_report to its internal queue, then asserts
  *      the CTDL_AP_IRQ signal to notify the AP.
  *